#include<iostream>
#include<vector>
#include<algorithm>

#define endl '\n'

using namespace std;

const int MOD=1e9+7;

void add_mod(int& x, int y){
    x+=y;
    if(x>=MOD){
        x-=MOD;
    }
}

int mul_mod(int x, int y){
    return 1ll*x*y%MOD;
}

struct TreeData {
    int measure,range;
    vector<int> prefix,suffix;

    TreeData(){
        measure=range=0;
    }

    TreeData(int val){
        range=1;
        measure=val;
        prefix.push_back(val);
        suffix.push_back(val);
    }
};

const int MAXN=1e6+3;
int nums[MAXN];
TreeData tree[MAXN];

TreeData merge_data(TreeData& segment1, TreeData& segment2){
    TreeData res;
    add_mod(res.measure, segment1.measure);
    add_mod(res.measure, segment2.measure);

    vector<int>& prefix1=segment1.prefix;
    vector<int>& suffix1=segment1.suffix;

    vector<int>& prefix2=segment2.prefix;
    vector<int>& suffix2=segment2.suffix;

    for(int i=0;i<segment1.range;++i){
        int curr=suffix2.end()-upper_bound(suffix2.begin(), suffix2.end(), prefix1[i]);
        add_mod(res.measure, mul_mod(prefix1[i], curr));
    }
    for(int i=0;i<segment2.range;++i){
        int curr=suffix1.end()-upper_bound(suffix1.begin(), suffix1.end(), prefix2[i]);
        add_mod(res.measure, mul_mod(prefix2[i], curr));
    }

    res.range=segment1.range+segment2.range;
    res.prefix=segment1.prefix;
    res.suffix=segment2.suffix;

    int prev=res.prefix.back();
    for(int i=0;i<segment2.range;++i){
        res.prefix.push_back(min(prev, segment2.prefix[i]));
        prev=res.prefix.back();
    }

    prev=res.suffix.back();
    for(int i=0;i<segment1.range;++i){
        res.suffix.push_back(min(prev, segment1.suffix[i]));
        prev=res.suffix.back();
    }
    reverse(res.suffix.begin(), res.suffix.end());

    return res;
}

void build_tree(int ind, int tl, int tr){
    if(tl==tr){
        tree[ind]=TreeData(nums[tl]);
        return;
    }

    int mid=(tl+tr)/2;
    build_tree(2*ind, tl, mid);
    build_tree(2*ind+1, mid+1, tr);

    tree[ind]=merge_data(tree[2*ind], tree[2*ind+1]);
}

int main(){
    ios::sync_with_stdio(false);
    cin.tie(nullptr);

    int n;
    cin>>n;

    for(int i=0;i<n;++i){
        cin>>nums[i];
    }

    build_tree(1, 0, n-1);
    int res=tree[1].measure;

    int q;
    cin>>q;

    while(q--){
        int ind,val;
        cin>>ind>>val;
    }

    cout<<res<<endl;
return 0;
}
